//+------------------------------------------------------------------+ 
//|              MULTI TIME FRAME MACD w optional Histo              | 
//|                WRITTEN AND DEVELOPED BY TIM HYDER                | 
//+------------------------------------------------------------------+ 
#property copyright "Copyright  2009, Pro4x.com"
#property link      "tim@pro4x.com"

#define vers   "21.Jan.2009"
#define major  "1"
#define minor  "1"
#define Build  "01"

//---- indicator settings
#property  indicator_separate_window
#property  indicator_buffers 4
#property  indicator_color1  clrLime
#property  indicator_width1  3
#property  indicator_color2  clrGreen
#property  indicator_width2  2
#property  indicator_color3  clrRed
#property  indicator_width3  3
#property  indicator_color4  clrMaroon
#property  indicator_width4  2

string NOTE1 = "===== TIME FRAME SETTINGS =====";
string NOTETF = "Enter 0 to display current TF";
int    TimeFrame = 0;

extern string _Settings = "===== INDICATOR SETTINGS =====";
extern int    FastEMA=12;
extern int    SlowEMA=26;
extern int    SignalSMA=9;

double ind_buffer1[], ind_buffer1s[];
double ind_buffer2[], ind_buffer2s[];
double ind_buffer3[], ind_buffer4[];

int TFrame;
double   PipPoint; //Default Point size for 4/5 digit pricing

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   //---- 1 additional buffer used for counting.
   IndicatorBuffers(6);
      
   SetIndexStyle(0,DRAW_HISTOGRAM);
   SetIndexStyle(1,DRAW_HISTOGRAM);
   SetIndexStyle(2,DRAW_HISTOGRAM);
   SetIndexStyle(3,DRAW_HISTOGRAM);
   SetIndexStyle(4,DRAW_NONE);
   SetIndexStyle(5,DRAW_NONE);
   IndicatorDigits(MarketInfo(Symbol(),MODE_DIGITS)+1);
   
   SetIndexDrawBegin(0,SlowEMA);
   SetIndexDrawBegin(1,SlowEMA);
   SetIndexDrawBegin(2,SlowEMA);
   SetIndexDrawBegin(3,SlowEMA);
   SetIndexDrawBegin(4,SlowEMA);
   SetIndexDrawBegin(5,SlowEMA);
   
   SetIndexBuffer(0,ind_buffer1);
   SetIndexBuffer(1,ind_buffer1s);
   SetIndexBuffer(2,ind_buffer2);
   SetIndexBuffer(3,ind_buffer2s);
   SetIndexBuffer(4,ind_buffer3);
   SetIndexBuffer(5,ind_buffer4);
   
   //Verify Time Values entered by user
   TFrame = CheckTimeFrame(TimeFrame);
   if(TFrame<Period()) TFrame = Period();

   //---- name for DataWindow and indicator subwindow label
   IndicatorShortName("Pro4x_MACD("+FastEMA+","+SlowEMA+","+SignalSMA+"), TF: " + TF2Str(TFrame) + "  ");

   return(0);
}
  
//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+  
void deinit()
{
  Comment("");
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int start()
{
   int    limit;
   int    counted_bars=IndicatorCounted();
//---- check for possible errors
   if(counted_bars<0) return(-1);
   //---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;
   limit=Bars-counted_bars;
   
  //-------------------------------1----------------------------------------   
   int i,y;
   datetime TimeArray[];
  
   // Plot defined time frame on to current time frame
   ArrayCopySeries(TimeArray,MODE_TIME,Symbol(),TFrame); 
   
   for(i=0,y=0;i<limit;i++)
   {
      if (Time[i]<TimeArray[y]) y++;      
      ind_buffer3[i]=iMACD(NULL,TFrame,FastEMA,SlowEMA,SignalSMA,PRICE_CLOSE,MODE_MAIN,y)*2;
      ind_buffer4[i]=iMACD(NULL,TFrame,FastEMA,SlowEMA,SignalSMA,PRICE_CLOSE,MODE_SIGNAL,y)*2;
   }
   
   //---- dispatch values between 2 buffers
   bool up=true;
   double MDM, MDS;
   for(i=limit-1; i>=0; i--)
   {
      MDM=ind_buffer3[i];
      MDS=ind_buffer4[i];
      
      up=False;
      if (MDM>=0) up=True;    
   
      ind_buffer1s[i]=0.0;
      ind_buffer1[i]=0.0;
      ind_buffer2[i]=0.0;
      ind_buffer2s[i]=0.0;

      
     if(up)
     {
        if(MDM>MDS) ind_buffer1[i]=MDM;
        else ind_buffer1s[i]=MDM;
     }
     else
     {
        if(MDM<MDS) ind_buffer2[i]=MDM;
        else ind_buffer2s[i]=MDM;
     }       
   }
//---- done
   return(0);
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+  
string TF2Str(int period) 
{
  switch (period) 
  {
    case PERIOD_M1: return("M1");
    case PERIOD_M5: return("M5");
    case PERIOD_M15: return("M15");
    case PERIOD_M30: return("M30");
    case PERIOD_H1: return("H1");
    case PERIOD_H4: return("H4");
    case PERIOD_D1: return("D1");
    case PERIOD_W1: return("W1");
    case PERIOD_MN1: return("MN");
  }
  return (Period());
} 

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+  
int CheckTimeFrame(int TF)
{
   int result;

   //If first time frame = 0 then default to currently displayed time frame
   if (TF == 0) 
      result = Period();   
   else
   {
      switch(TF) 
      {
         case 1    : result = PERIOD_M1;  break; 
         case 5    : result = PERIOD_M5;  break;
         case 15   : result = PERIOD_M15; break;
         case 30   : result = PERIOD_M30; break;
         case 60   : result = PERIOD_H1;  break;
         case 240  : result = PERIOD_H4;  break;
         case 1440 : result = PERIOD_D1;  break;
         case 10080 : result = PERIOD_W1;  break;
         case 43200: result = PERIOD_MN1; break;
         default  : result = Period(); break; //Error so return 0
      }
   }
   return(result);
}

//+----------------------End Program--------------------------------------------+