//+------------------------------------------------------------------+ 
//|                Scalping MAs with Spacing Highlight               | 
//|                WRITTEN AND DEVELOPED BY TIM HYDER                | 
//+------------------------------------------------------------------+ 
#property copyright "Copyright  2015, Pro4x.com"
#property link      "tim@pro4x.com"

#define vers   "14.Feb.2015"
#define major  "1"
#define minor  "0"

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
#property indicator_chart_window
#property indicator_buffers 3
#property indicator_color1 clrGreen
#property indicator_color2 clrRed
#property indicator_color3 clrBlue

#property indicator_width1 2
#property indicator_width2 2
#property indicator_width3 2

extern int    MA1_Pd           = 5;
extern int    MA2_Pd           = 40;
extern double MinSpacingM1     = 10;     
extern double MinSpacingM5     = 15;     
extern double MinSpacingM15    = 30;     
extern double MinSpacingM30    = 40;     
extern double MinSpacingH1     = 60;     
extern double MinSpacingH4     = 100;     
extern double MinSpacingD1     = 150;     
extern bool   HighlightSpacing = True;

extern string Alerts = "===== ALERT OPTIONS =====";
extern bool   UseAlerts   = False;
extern bool   MsgAlerts   = True;
extern bool   SoundAlerts = True;
string AlertSoundFile  = "alert.wav";
extern bool   eMailAlerts = False;

double MA1[],MA2[],Highlight[];

int TFrame, LastAlertBar;
string iName = "ScalpMAs";
bool NewCross;
bool Loading;
double MinSpacing;

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
int init()
{
   SetIndexStyle(0,DRAW_LINE);
   SetIndexBuffer(0,MA1);

   SetIndexStyle(1,DRAW_LINE);
   SetIndexBuffer(1,MA2);
   
   SetIndexBuffer(2,Highlight);
   SetIndexStyle(2,DRAW_ARROW);
   SetIndexArrow(2,167);
   
   IndicatorShortName(iName);
   LastAlertBar = Bars;
   Loading = True;

   switch(Period())
   {
      case PERIOD_M1:  MinSpacing=MinSpacingM1; break;
      case PERIOD_M5:  MinSpacing=MinSpacingM5; break;
      case PERIOD_M15: MinSpacing=MinSpacingM15; break;
      case PERIOD_M30: MinSpacing=MinSpacingM30; break;
      case PERIOD_H1:  MinSpacing=MinSpacingH1; break;
      case PERIOD_H4:  MinSpacing=MinSpacingH4; break;
      default:       MinSpacing=MinSpacingD1; break;
   }
   MinSpacing *= GetPointSize(Symbol());

   return(0);
  }
//+------------------------------------------------------------------+
//| Custor indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
//---- TODO: add your code here
   Comment("");
//----
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start() 
{  
   int    counted_bars=IndicatorCounted();
   //---- check for possible errors
   if(counted_bars<0) return(-1);
   //---- last counted bar will be recounted
   if(counted_bars>0) counted_bars--;
   int limit=Bars-counted_bars;
       
   for(int i=limit;i>=0;i--)
   {

      MA1[i] = iMA(Symbol(), Period(), MA1_Pd, 1, MODE_EMA, PRICE_CLOSE, i);
      MA2[i] = iMA(Symbol(), Period(), MA2_Pd, 0, MODE_EMA, PRICE_CLOSE, i);
      Highlight[i]=EMPTY_VALUE;
      if(MA1[i]>MA2[i] && High[i]-MA2[i]>MinSpacing) Highlight[i]=MA2[i];
      if(MA1[i]<MA2[i] && MA2[i]-Low[i]>MinSpacing) Highlight[i]=MA2[i];

      if(!Loading)
      {
         if(MA1[i+1]>MA2[i+1] && MA1[i]<MA2[i]) NewCross=TRUE;
         if(MA1[i+1]<MA2[i+1] && MA1[i]>MA2[i]) NewCross=True;
      }
   }
   
   if(UseAlerts)
   {
      int Signal = 0;
      string line = "";
      if(NewCross && Highlight[1]!=EMPTY_VALUE && LastAlertBar != Bars)
      {
         NewCross = False;         
         LastAlertBar = Bars;
         string Subj = Symbol()+ ", " + TF2Str(Period()) + " Scalp MA Spacing Alert"; 
         string Msg = Subj;
         DoAlerts(Msg,Subj,AlertSoundFile);
      }           
   }

   Loading=False;
   return(0);
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
string TF2Str(int period) 
{
  switch (period) 
  {
    case PERIOD_M1: return("M1");
    case PERIOD_M5: return("M5");
    case PERIOD_M15: return("M15");
    case PERIOD_M30: return("M30");
    case PERIOD_H1: return("H1");
    case PERIOD_H4: return("H4");
    case PERIOD_D1: return("D1");
    case PERIOD_W1: return("W1");
    case PERIOD_MN1: return("MN");
  }
  return (Period());
} 

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
void DoAlerts(string msgText,string eMailSub, string SoundAlertFile)
{
   if (MsgAlerts) Alert(msgText);
   if (SoundAlerts)  PlaySound(SoundAlertFile);
   if (eMailAlerts) SendMail(eMailSub, msgText);
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
bool IsSilver(string Symb)
{
   string sUpper = Symb;
   bool b = StringToUpper(sUpper);
   if(StringFind(sUpper, "SILVER", 0) >=0) return(True);
   if(StringFind(sUpper, "XAG", 0) >=0) return(True);
   return(False);
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
bool IsGold(string Symb)
{
   string sUpper = Symb;
   bool b = StringToUpper(sUpper);
   if(StringFind(sUpper, "XAU", 0) >=0) return(True);
   if(StringFind(sUpper, "GOLD", 0) >=0) return(True);
   if(StringFind(sUpper, "GLD", 0) >=0) return(True);
   return(False);
}

//+------------------------------------------------------------------+
//|                                                                  |
//+------------------------------------------------------------------+
double GetPointSize(string Sym)
{
   //JPY first as most other pairs are crosses of it and hence will return incorrect values
   if(StringFind(Sym, "JPY", 0) != -1) return(0.01);  
   if(StringFind(Sym, "OIL", 0) != -1) return(0.01);  
   if(StringFind(Sym, "AUS200", 0) != -1) return(1);  
   if(StringFind(Sym, "GER30", 0) != -1) return(1);  
   if(StringFind(Sym, "UK100", 0) != -1) return(1);  
   if(StringFind(Sym, "SPX500", 0) != -1) return(1);  
   if(IsGold(Sym)) return(0.1);
   if(IsSilver(Sym)) return(0.01);

   double Pt = 0.0001;
   //Dont check for USD as a US based futures may have these three letters in it.
   //if we check on all other cross pairs then this we should be able to get all main fx pairs
   if(StringFind(Sym, "EUR", 0) != -1) return(Pt);     
   if(StringFind(Sym, "GBP", 0) != -1) return(Pt);  
   if(StringFind(Sym, "AUD", 0) != -1) return(Pt);  
   if(StringFind(Sym, "CAD", 0) != -1) return(Pt);  
   if(StringFind(Sym, "CHF", 0) != -1) return(Pt);  
   if(StringFind(Sym, "NZD", 0) != -1) return(Pt);  
   if(StringFind(Sym, "SGD", 0) != -1) return(Pt);  
   if(StringFind(Sym, "SEK", 0) != -1) return(Pt);  
   if(StringFind(Sym, "DKK", 0) != -1) return(Pt);  
   if(StringFind(Sym, "HKD", 0) != -1) return(Pt);  
   if(StringFind(Sym, "ZAR", 0) != -1) return(Pt);  

   double dgts = MarketInfo(Sym,MODE_DIGITS);
   if(dgts < 4) return(0.01); 
   return(MarketInfo(Sym,MODE_POINT));
}

//+----------------------End Program--------------------------------------------+